.. highlight:: shell

============
Installation
============

Requirements
------------

rf-info requires the iso3166 library, and the colorama library for the command line.
These are automatically installed when rf-info is installed.

     
Stable Version
--------------

To install rf-info, run this command in your terminal:

.. code-block:: console

    $ pip install rf-info

This is the preferred method to install rf-info, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io/en/stable/
.. _Python installation guide: https://docs.python-guide.org/starting/installation/ 


Latest Version from sources
---------------------------

The sources for rf-info can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/cosmicc/rf_info

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/cosmicc/rf_info/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/cosmicc/rf_info
.. _tarball: https://github.com/cosmicc/rf_info/tarball/master
